;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dylan" "20250319.1925"
  "Dylan editing modes."
  '((emacs "25.1"))
  :url "https://opendylan.org/"
  :commit "342d86a58ad307a581fc95c0f271661444dbc13c"
  :revdesc "342d86a58ad3")
